==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/General/rgscan/translations/rgscan_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>RGScanDialog</name>
    <message>
        <location filename="../rgscandialog.ui" line="14"/>
        <source>ReplayGain Scanner</source>
        <translation>Сканер ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="84"/>
        <source>Write track gain/peak</source>
        <translation>Записувати пік/підсилення для треку</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="42"/>
        <source>Title</source>
        <translation>Назва</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="47"/>
        <source>Progress</source>
        <translation>Прогрес</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="52"/>
        <source>Track Gain</source>
        <translation>Підсилення треку</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="57"/>
        <source>Album Gain</source>
        <translation>Підсилення альбому</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="62"/>
        <source>Track Peak</source>
        <translation>Пік треку</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="67"/>
        <source>Album Peak</source>
        <translation>Пік альбому</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="77"/>
        <source>Skip already scanned files</source>
        <translation>Пропустити вже відскановані файли</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="113"/>
        <source>Calculate</source>
        <translation>Розрахувати</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="120"/>
        <source>Write Tags</source>
        <translation>Записати теги</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="91"/>
        <source>Write album gain/peak</source>
        <translation>Записувати пік/підсилення для альбому</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="122"/>
        <location filename="../rgscandialog.cpp" line="233"/>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="132"/>
        <location filename="../rgscandialog.cpp" line="133"/>
        <location filename="../rgscandialog.cpp" line="157"/>
        <location filename="../rgscandialog.cpp" line="228"/>
        <source>%1 dB</source>
        <translation>%1 дБ</translation>
    </message>
</context>
<context>
    <name>RGScanFactory</name>
    <message>
        <location filename="../rgscanfactory.cpp" line="29"/>
        <source>ReplayGain Scanner Plugin</source>
        <translation>Модуль сканування ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="50"/>
        <source>About ReplayGain Scanner Plugin</source>
        <translation>Про модуль сканування ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="51"/>
        <source>ReplayGain Scanner Plugin for Qmmp</source>
        <translation>Модуль сканування ReplayGain для Qmmp</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="52"/>
        <source>This plugin scans audio files and gives information for volume normalization</source>
        <translation>Цей модуль сканує аудіо файли і видає інформацію для нормалізації гучності</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="54"/>
        <source>Based on source code by:</source>
        <translation>Заснований на вихідному коді наступних розробників:</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="55"/>
        <source>David Robinson &lt;David@Robinson.org&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="56"/>
        <source>Glen Sawyer &lt;mp3gain@hotmail.com&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="57"/>
        <source>Frank Klemm</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>RGScanHelper</name>
    <message>
        <location filename="../rgscanhelper.cpp" line="32"/>
        <source>ReplayGain Scanner</source>
        <translation>Сканер ReplaGain</translation>
    </message>
    <message>
        <location filename="../rgscanhelper.cpp" line="33"/>
        <source>Meta+R</source>
        <translation></translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/General/rgscan/translations/rgscan_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>RGScanDialog</name>
    <message>
        <location filename="../rgscandialog.ui" line="14"/>
        <source>ReplayGain Scanner</source>
        <translation>Сканер ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="84"/>
        <source>Write track gain/peak</source>
        <translation>Записувати пік/підсилення для треку</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="42"/>
        <source>Title</source>
        <translation>Назва</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="47"/>
        <source>Progress</source>
        <translation>Прогрес</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="52"/>
        <source>Track Gain</source>
        <translation>Підсилення треку</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="57"/>
        <source>Album Gain</source>
        <translation>Підсилення альбому</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="62"/>
        <source>Track Peak</source>
        <translation>Пік треку</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="67"/>
        <source>Album Peak</source>
        <translation>Пік альбому</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="77"/>
        <source>Skip already scanned files</source>
        <translation>Пропустити вже відскановані файли</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="113"/>
        <source>Calculate</source>
        <translation>Розрахувати</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="120"/>
        <source>Write Tags</source>
        <translation>Записати теги</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="91"/>
        <source>Write album gain/peak</source>
        <translation>Записувати пік/підсилення для альбому</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="122"/>
        <location filename="../rgscandialog.cpp" line="233"/>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="132"/>
        <location filename="../rgscandialog.cpp" line="133"/>
        <location filename="../rgscandialog.cpp" line="157"/>
        <location filename="../rgscandialog.cpp" line="228"/>
        <source>%1 dB</source>
        <translation>%1 дБ</translation>
    </message>
</context>
<context>
    <name>RGScanFactory</name>
    <message>
        <location filename="../rgscanfactory.cpp" line="29"/>
        <source>ReplayGain Scanner Plugin</source>
        <translation>Модуль сканування ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="50"/>
        <source>About ReplayGain Scanner Plugin</source>
        <translation>Про модуль сканування ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="51"/>
        <source>ReplayGain Scanner Plugin for Qmmp</source>
        <translation>Модуль сканування ReplayGain для Qmmp</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="52"/>
        <source>This plugin scans audio files and gives information for volume normalization</source>
        <translation>Цей модуль сканує аудіо файли і видає інформацію для нормалізації гучності</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="54"/>
        <source>Based on source code by:</source>
        <translation>Заснований на вихідному коді наступних розробників:</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="55"/>
        <source>David Robinson &lt;David@Robinson.org&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="56"/>
        <source>Glen Sawyer &lt;mp3gain@hotmail.com&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="57"/>
        <source>Frank Klemm</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>RGScanHelper</name>
    <message>
        <location filename="../rgscanhelper.cpp" line="32"/>
        <source>ReplayGain Scanner</source>
        <translation>Сканер ReplaGain</translation>
    </message>
    <message>
        <location filename="../rgscanhelper.cpp" line="33"/>
        <source>Meta+R</source>
        <translation></translation>
    </message>
</context>
</TS>
